@@ -4,9 +4,9 @@ Main interface for backup service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_backup.type_defs import BackupJobTypeDef
+    from mypy_boto3_backup.type_defs import AdvancedBackupSettingTypeDef
 
-    data: BackupJobTypeDef = {...}
+    data: AdvancedBackupSettingTypeDef = {...}
     ```
 """
 import sys
@@ -27,6 +27,7 @@ else:
 
 
 __all__ = (
+    "AdvancedBackupSettingTypeDef",
     "BackupJobTypeDef",
     "BackupPlanTemplatesListMemberTypeDef",
     "BackupPlanTypeDef",
@@ -86,6 +87,12 @@ __all__ = (
     "UpdateRecoveryPointLifecycleOutputTypeDef",
 )
 
+AdvancedBackupSettingTypeDef = TypedDict(
+    "AdvancedBackupSettingTypeDef",
+    {"ResourceType": str, "BackupOptions": Dict[str, str]},
+    total=False,
+)
+
 BackupJobTypeDef = TypedDict(
     "BackupJobTypeDef",
     {
@@ -109,6 +116,8 @@ BackupJobTypeDef = TypedDict(
         "StartBy": datetime,
         "ResourceType": str,
         "BytesTransferred": int,
+        "BackupOptions": Dict[str, str],
+        "BackupType": str,
     },
     total=False,
 )
@@ -119,9 +128,19 @@ BackupPlanTemplatesListMemberTypeDef = TypedDict(
     total=False,
 )
 
-BackupPlanTypeDef = TypedDict(
-    "BackupPlanTypeDef", {"BackupPlanName": str, "Rules": List["BackupRuleTypeDef"]}
+_RequiredBackupPlanTypeDef = TypedDict(
+    "_RequiredBackupPlanTypeDef", {"BackupPlanName": str, "Rules": List["BackupRuleTypeDef"]}
 )
+_OptionalBackupPlanTypeDef = TypedDict(
+    "_OptionalBackupPlanTypeDef",
+    {"AdvancedBackupSettings": List["AdvancedBackupSettingTypeDef"]},
+    total=False,
+)
+
+
+class BackupPlanTypeDef(_RequiredBackupPlanTypeDef, _OptionalBackupPlanTypeDef):
+    pass
+
 
 BackupPlansListMemberTypeDef = TypedDict(
     "BackupPlansListMemberTypeDef",
@@ -134,6 +153,7 @@ BackupPlansListMemberTypeDef = TypedDict(
         "BackupPlanName": str,
         "CreatorRequestId": str,
         "LastExecutionDate": datetime,
+        "AdvancedBackupSettings": List["AdvancedBackupSettingTypeDef"],
     },
     total=False,
 )
@@ -338,13 +358,30 @@ RestoreJobsListMemberTypeDef = TypedDict(
     total=False,
 )
 
-BackupPlanInputTypeDef = TypedDict(
-    "BackupPlanInputTypeDef", {"BackupPlanName": str, "Rules": List["BackupRuleInputTypeDef"]}
+_RequiredBackupPlanInputTypeDef = TypedDict(
+    "_RequiredBackupPlanInputTypeDef",
+    {"BackupPlanName": str, "Rules": List["BackupRuleInputTypeDef"]},
 )
+_OptionalBackupPlanInputTypeDef = TypedDict(
+    "_OptionalBackupPlanInputTypeDef",
+    {"AdvancedBackupSettings": List["AdvancedBackupSettingTypeDef"]},
+    total=False,
+)
+
+
+class BackupPlanInputTypeDef(_RequiredBackupPlanInputTypeDef, _OptionalBackupPlanInputTypeDef):
+    pass
+
 
 CreateBackupPlanOutputTypeDef = TypedDict(
     "CreateBackupPlanOutputTypeDef",
-    {"BackupPlanId": str, "BackupPlanArn": str, "CreationDate": datetime, "VersionId": str},
+    {
+        "BackupPlanId": str,
+        "BackupPlanArn": str,
+        "CreationDate": datetime,
+        "VersionId": str,
+        "AdvancedBackupSettings": List["AdvancedBackupSettingTypeDef"],
+    },
     total=False,
 )
 
@@ -389,6 +426,8 @@ DescribeBackupJobOutputTypeDef = TypedDict(
         "BytesTransferred": int,
         "ExpectedCompletionDate": datetime,
         "StartBy": datetime,
+        "BackupOptions": Dict[str, str],
+        "BackupType": str,
     },
     total=False,
 )
@@ -491,6 +530,7 @@ GetBackupPlanOutputTypeDef = TypedDict(
         "CreationDate": datetime,
         "DeletionDate": datetime,
         "LastExecutionDate": datetime,
+        "AdvancedBackupSettings": List["AdvancedBackupSettingTypeDef"],
     },
     total=False,
 )
@@ -636,7 +676,13 @@ StartRestoreJobOutputTypeDef = TypedDict(
 
 UpdateBackupPlanOutputTypeDef = TypedDict(
     "UpdateBackupPlanOutputTypeDef",
-    {"BackupPlanId": str, "BackupPlanArn": str, "CreationDate": datetime, "VersionId": str},
+    {
+        "BackupPlanId": str,
+        "BackupPlanArn": str,
+        "CreationDate": datetime,
+        "VersionId": str,
+        "AdvancedBackupSettings": List["AdvancedBackupSettingTypeDef"],
+    },
     total=False,
 )
 
